aboutsummaryrefslogtreecommitdiffstats
path: root/matrix-sync.h
diff options
context:
space:
mode:
authorRichard van der Hoff <richard@matrix.org>2015-10-22 15:56:55 +0100
committerRichard van der Hoff <richard@matrix.org>2015-10-22 15:56:55 +0100
commite8c4ddde265c060eb1466f39d3feb09694dd3482 (patch)
tree33b0aa94169c2c4b3524bb24b174336851ad5581 /matrix-sync.h
parent8b8a74532d6998c58dbfc095e6e5feab1739a95b (diff)
downloadpurple-matrix-e8c4ddde265c060eb1466f39d3feb09694dd3482.tar.gz
Rename MatrixAccount to MatrixConnectionData
This structure comes and goes with each connection, so rename it to better reflect its lifecycle.
Diffstat (limited to 'matrix-sync.h')
-rw-r--r--matrix-sync.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/matrix-sync.h b/matrix-sync.h
index 629f493..4f267dc 100644
--- a/matrix-sync.h
+++ b/matrix-sync.h
@@ -3,7 +3,7 @@
*
* Receipt of events from the matrix homeserver works by continually polling the
* /sync API endpoint. This module manages that process. It provides a single
* method which initiates a /sync request for an authenticated MatrixAccount.
*
* On completion of the request, any events it returned are dispatched to the
* relevant rooms, and another /sync request is started.
@@ -33,6 +33,6 @@
* Start the sync loop for a matrix account. This will repeatedly call
* '/sync' to get room information and new events.
*/
-void matrix_sync_start_loop(MatrixAccount *ma);
+void matrix_sync_start_loop(MatrixConnectionData *ma);
#endif /* MATRIX_SYNC_H_ */
@@ -3,7 +3,7 @@
* Receipt of events from the matrix homeserver works by continually polling the
* /sync API endpoint. This module manages that process. It provides a single
- * method which initiates a /sync request for an authenticated MatrixAccount.
+ * method which initiates a /sync request for an authenticated MatrixConnectionData.
*
* On completion of the request, any events it returned are dispatched to the